@@ -82,5 +82,5 @@ def SimpleConsoleMenu(menuName,menuItems,inputQuestion,autoAddQuit = False,onlyR
         else:
             return choose
 
-print(SimpleConsoleMenu('menu','item1;item2','Number:',True,False,'a;b','c'))
+# print(SimpleConsoleMenu('menu','item1;item2','Number:',True,False,'a;b','c'))
                     
\ No newline at end of file
